Struct owned_pin::sync::RefCount

source ·
pub struct RefCount { /* private fields */ }
An intrusive reference counter.

Users should place this structure into their own type, and implement RefCounted to enable the support for intrusive ref-counting.

The ways to initialize a RefCount is only to use its new method or use the Default trait.

For users who want some unsafe hints, when some type including this structure wants to implement Clone, a new instance of RefCount should be assigned to the cloned value, or undefined behavior will happen in place. Hence, no “byte copying” should be considered.

Implementations

source

impl RefCount

source

pub const fn new() -> Self

Creates a new intrusive reference counter.

The user should not and cannot modify this structure by any means.

source

pub fn get(&self) -> usize

Retrives the current reference count.

The user should not and cannot modify this structure by any means.